@@ -16,19 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.beyondcorp_appconnectors_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -36,14 +48,6 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.beyondcorp_appconnectors_v1.services.app_connectors_service import (
-    pagers,
-)
-from google.cloud.beyondcorp_appconnectors_v1.types import app_connectors_service
-from google.cloud.beyondcorp_appconnectors_v1.types import resource_info
-from google.cloud.beyondcorp_appconnectors_v1.types import (
-    resource_info as gcba_resource_info,
-)
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
@@ -51,7 +55,17 @@ from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AppConnectorsServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.beyondcorp_appconnectors_v1.services.app_connectors_service import (
+    pagers,
+)
+from google.cloud.beyondcorp_appconnectors_v1.types import app_connectors_service
+from google.cloud.beyondcorp_appconnectors_v1.types import (
+    resource_info as gcba_resource_info,
+)
+from google.cloud.beyondcorp_appconnectors_v1.types import resource_info
+
+from .transports.base import DEFAULT_CLIENT_INFO, AppConnectorsServiceTransport
 from .transports.grpc import AppConnectorsServiceGrpcTransport
 from .transports.grpc_asyncio import AppConnectorsServiceGrpcAsyncIOTransport
 from .transports.rest import AppConnectorsServiceRestTransport
@@ -74,7 +88,7 @@ class AppConnectorsServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[AppConnectorsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -95,10 +109,14 @@ class AppConnectorsServiceClientMeta(type):
 
 
 class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
-    """API Overview: The ``beyondcorp.googleapis.com`` service implements the Google
+    """API Overview:
+
+    The ``beyondcorp.googleapis.com`` service implements the Google
     Cloud BeyondCorp API.
 
-    Data Model: The AppConnectorsService exposes the following resource:
+    Data Model:
+
+    The AppConnectorsService exposes the following resource:
 
     -  AppConnectors, named as follows:
        ``projects/{project_id}/locations/{location_id}/appConnectors/{app_connector_id}``.
@@ -359,8 +377,8 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, AppConnectorsServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, AppConnectorsServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the app connectors service client.
@@ -374,10 +392,7 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
             transport (Union[str, AppConnectorsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-                NOTE: "rest" transport functionality is currently in a
-                beta state (preview). We welcome your feedback via an
-                issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -407,6 +422,7 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -459,11 +475,13 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def list_app_connectors(
         self,
-        request: Union[app_connectors_service.ListAppConnectorsRequest, dict] = None,
+        request: Optional[
+            Union[app_connectors_service.ListAppConnectorsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAppConnectorsPager:
         r"""Lists AppConnectors in a given project and location.
@@ -575,11 +593,13 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def get_app_connector(
         self,
-        request: Union[app_connectors_service.GetAppConnectorRequest, dict] = None,
+        request: Optional[
+            Union[app_connectors_service.GetAppConnectorRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> app_connectors_service.AppConnector:
         r"""Gets details of a single AppConnector.
@@ -685,13 +705,15 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def create_app_connector(
         self,
-        request: Union[app_connectors_service.CreateAppConnectorRequest, dict] = None,
+        request: Optional[
+            Union[app_connectors_service.CreateAppConnectorRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        app_connector: app_connectors_service.AppConnector = None,
-        app_connector_id: str = None,
+        parent: Optional[str] = None,
+        app_connector: Optional[app_connectors_service.AppConnector] = None,
+        app_connector_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new AppConnector in a given project and
@@ -836,12 +858,14 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def update_app_connector(
         self,
-        request: Union[app_connectors_service.UpdateAppConnectorRequest, dict] = None,
+        request: Optional[
+            Union[app_connectors_service.UpdateAppConnectorRequest, dict]
+        ] = None,
         *,
-        app_connector: app_connectors_service.AppConnector = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        app_connector: Optional[app_connectors_service.AppConnector] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates the parameters of a single AppConnector.
@@ -977,11 +1001,13 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def delete_app_connector(
         self,
-        request: Union[app_connectors_service.DeleteAppConnectorRequest, dict] = None,
+        request: Optional[
+            Union[app_connectors_service.DeleteAppConnectorRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single AppConnector.
@@ -1101,12 +1127,14 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def report_status(
         self,
-        request: Union[app_connectors_service.ReportStatusRequest, dict] = None,
+        request: Optional[
+            Union[app_connectors_service.ReportStatusRequest, dict]
+        ] = None,
         *,
-        app_connector: str = None,
-        resource_info: gcba_resource_info.ResourceInfo = None,
+        app_connector: Optional[str] = None,
+        resource_info: Optional[gcba_resource_info.ResourceInfo] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Report status for a given connector.
@@ -1250,10 +1278,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -1304,10 +1332,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1358,10 +1386,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -1413,10 +1441,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -1467,10 +1495,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.SetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM access control policy on the specified function.
@@ -1587,10 +1615,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.GetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM access control policy for a function.
@@ -1708,10 +1736,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Optional[iam_policy_pb2.TestIamPermissionsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Tests the specified IAM permissions against the IAM access control
@@ -1767,10 +1795,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -1821,10 +1849,10 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
 
     def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -1874,14 +1902,9 @@ class AppConnectorsServiceClient(metaclass=AppConnectorsServiceClientMeta):
         return response
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-beyondcorp-appconnectors",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AppConnectorsServiceClient",)
