@@ -13,34 +13,35 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
-import grpc  # type: ignore
-
-from google.cloud.beyondcorp_appconnectors_v1.types import app_connectors_service
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
-from google.longrunning import operations_pb2
 from google.longrunning import operations_pb2  # type: ignore
-from .base import AppConnectorsServiceTransport, DEFAULT_CLIENT_INFO
+import grpc  # type: ignore
+
+from google.cloud.beyondcorp_appconnectors_v1.types import app_connectors_service
+
+from .base import DEFAULT_CLIENT_INFO, AppConnectorsServiceTransport
 
 
 class AppConnectorsServiceGrpcTransport(AppConnectorsServiceTransport):
     """gRPC backend transport for AppConnectorsService.
 
-    API Overview: The ``beyondcorp.googleapis.com`` service implements the Google
+    API Overview:
+
+    The ``beyondcorp.googleapis.com`` service implements the Google
     Cloud BeyondCorp API.
 
-    Data Model: The AppConnectorsService exposes the following resource:
+    Data Model:
+
+    The AppConnectorsService exposes the following resource:
 
     -  AppConnectors, named as follows:
        ``projects/{project_id}/locations/{location_id}/appConnectors/{app_connector_id}``.
@@ -62,14 +63,14 @@ class AppConnectorsServiceGrpcTransport(AppConnectorsServiceTransport):
         self,
         *,
         host: str = "beyondcorp.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        channel: grpc.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        channel: Optional[grpc.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -197,8 +198,8 @@ class AppConnectorsServiceGrpcTransport(AppConnectorsServiceTransport):
     def create_channel(
         cls,
         host: str = "beyondcorp.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         **kwargs,
